.. careBT documentation master file, created by
   sphinx-quickstart on Fri Nov  5 22:33:15 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

careBT - contingency aware Behavior Trees
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Basics:

   introduction
   installation
   design

.. toctree::
   :maxdepth: 2
   :caption: careBT Reference:

   api/overview
   api/carebt

.. toctree::
   :maxdepth: 1
   :caption: Tutorials:

   tutorial/introduction
   tutorial/helloworld
   tutorial/action_with_params
   tutorial/simple_sequence
   tutorial/understanding_contingeny-handler
   tutorial/longrun_actions
   tutorial/simple_fallback
   tutorial/simple_parallel
   tutorial/simple_ratecontrol